
#ifndef _GLAZLIB_H
#define _GLAZLIB_H

#define ERROR_NONE							0
#define ERROR_NOT_INITIALISED               1
#define ERROR_SCRIPT                        2
#define ERROR_CONNECTING_TO_CAMERAS	        3
#define ERROR_DOWNLOADING_CALIBRATIONS      4
#define ERROR_INVALID_WAVELENGTHS           5
#define ERROR_INVALID_AVERAGING             6
#define ERROR_INVALID_SCAN_COUNT            7
#define ERROR_INVALID_TRIGGER_MODE          8
#define ERROR_INVALID_TRIGGER_DELAY         9
#define ERROR_INVALID_INTEGRATION_TIME     10
#define ERROR_INVALID_SCAN_CLOCK_SPEED     11
#define ERROR_INVALID_SETTINGS             12
#define ERROR_CAPTURING_BACKGROUNDS        13
#define ERROR_RUNNING_MEASUREMENT          14
#define ERROR_INVALID_CALCULATION_INDEX    15
#define ERROR_INVALID_RESULT_DATA_SIZE     16
#define ERROR_INVALID_PD_NUMBER            17
#define ERROR_INVALID_PD_CHANNEL           18
#define ERROR_INVALID_CAMERA_NUMBER        19
#define ERROR_INVALID_TRIGGER_FREQUENCY    20
#define ERROR_NO_MEASUREMENT_RUN           21
#define ERROR_INITIALISING_SINGEL_DEVICE   22
#define ERROR_INVALID_SINGLE_DEVICE_TYPE   23
#define ERROR_INVALID_SYNC_OUT_MODE        24
#define ERROR_INVALID_INTEGRATION_MODE     25
#define ERROR_CLOCK_SPEED_UNSUPPORTED      26
#define ERROR_INVALID_AUX_OUT_MODE         27
#define ERROR_CYCLE_COUNT_UNSUPPORTED      28
#define ERROR_INVALID_CYCLE_COUNT          29
#define ERROR_INVALID_TEST_MODE            30
#define ERROR_OUT_POLARITY_NOT_SUPPORTED   31
#define ERROR_INVALID_OUT_POLARITY         32
#define ERROR_RESOLUTION_OUT_OF_RANGE      33
#define ERROR_RESOLUTION_NOT_SUPPORTED     34
#define ERROR_RUNNING_USB_COMMS_TEST       35
#define ERROR_MEASUREMENT_STREAM           36
#define ERROR_AUX_STATES_NOT_SUPPORTED     37

#define GLAZ_LINESCAN_I_PULSESYNC_S10453_SINGLE_DEVICE_TYPE   1
#define GLAZ_LINESCAN_I_PULSESYNC_S11639_SINGLE_DEVICE_TYPE   2
#define GLAZ_LINESCAN_I_TIMEFILL_S11639_SINGLE_DEVICE_TYPE    3
#define GLAZ_LINESCAN_I_SPECTROCAM_S11639_SINGLE_DEVICE_TYPE  4
#define GLAZ_LINESCAN_II_SINGLE_DEVICE_TYPE                   5
#define GLAZ_LINESCAN_II_V2_SINGLE_DEVICE_TYPE                6
#define GLAZ_LINESCAN_LS_SINGLE_DEVICE_TYPE                   7

#define AVERAGING_X1      0
#define AVERAGING_X2      1
#define AVERAGING_X4      2
#define AVERAGING_X8      3
#define AVERAGING_X16     4
#define AVERAGING_X32     5
#define AVERAGING_X64     6
#define AVERAGING_X128    7
#define AVERAGING_X256    8
#define AVERAGING_X512    9
#define AVERAGING_X1024  10
#define AVERAGING_X2048  11
#define AVERAGING_X4096  12

#define RESOLUTION_16BIT    3
#define RESOLUTION_14BIT    2
#define RESOLUTION_12BIT    1
#define RESOLUTION_10BIT    0

#define TRIGGER_EXTERNAL    0
#define TRIGGER_INTERNAL    1
#define TRIGGER_BURST       2

#define INT_MODE_PULSESYNC  0
#define INT_MODE_TIMEFILL   1

#define OUT_INT_WINDOW              0
#define OUT_TRIGGER                 1
#define OUT_BUSY                    2
#define OUT_TRIGGER_CYCLE_START     3
#define OUT_TRIGGER_CYCLE_RUNNING   4
#define OUT_OFF                     5

#define OUT_POLARITY_ACTIVE_HI      1
#define OUT_POLARITY_ACTIVE_LO      0

#define SCAN_CLOCK_FULL_SPEED   0
#define SCAN_CLOCK_HALF_SPEED   1

#define TEST_OFF                0
#define TEST_DAC_ALTERNATING    1
#define TEST_DAC_ALL_ONES       2
#define TEST_DAC_ALL_ZEROS      3

#ifdef _WIN32
    #define DECLSPEC __declspec(dllexport)
    #define CDECL __cdecl
#else
    #define DECLSPEC
    #define CDECL
#endif

#ifdef __cplusplus
extern "C" {
#endif

DECLSPEC void CDECL getVersion(int* majorVersion, int* minorVersion);
DECLSPEC void CDECL getUSBParameters(int* latency, int* transferSize, int* blockSize);
DECLSPEC void CDECL setUSBParameters(int latency, int transferSize, int blockSize);

DECLSPEC void CDECL enableDataStreamLog(bool enabled);    

DECLSPEC int CDECL initialiseSession(const char* scriptFileName);
DECLSPEC int CDECL initialiseSingleDeviceSession(int singelDeviceType, bool keepScans, bool reverse);
DECLSPEC int CDECL closeSession();

DECLSPEC void CDECL resetAllDevices();
DECLSPEC void CDECL resetAllPorts();

DECLSPEC int CDECL setTestMode(int testMode);

DECLSPEC int CDECL setWavelengths(double lambdaMin, double lambdaMax);
DECLSPEC int CDECL setHardwareAveraging(int averaging);
DECLSPEC int CDECL setResolution(int resolution);
DECLSPEC int CDECL setScanCount(int scanCount);
DECLSPEC int CDECL setScanClockSpeed(int speed);

DECLSPEC int CDECL setTriggerDelay(int us);
DECLSPEC int CDECL setTriggerMode(int mode);
DECLSPEC int CDECL setInternalTriggerFrequency(double Hz);

DECLSPEC int CDECL setIntegrationMode(int mode);
DECLSPEC int CDECL setIntegrationTime(int us);

DECLSPEC int CDECL setSyncOutMode(int mode);
DECLSPEC int CDECL setSyncOutPolarity(int polarity);
DECLSPEC int CDECL setAuxOutMode(int mode);
DECLSPEC int CDECL setAuxOutPolarity(int polarity);
DECLSPEC int CDECL setOutCycleCount(int cycleCount);

DECLSPEC int CDECL setTimeout(int ms);

DECLSPEC int CDECL captureBackground(int scanCount);
DECLSPEC int CDECL runMeasurement();
DECLSPEC int CDECL startMeasurement();
DECLSPEC int CDECL isMeasurementDone(bool* isDone);

DECLSPEC int CDECL getResult(int calculationIndex, int* count, double* values);
DECLSPEC int CDECL getComplexResult(int calculationIndex, int* count, double* real, double* imag);

DECLSPEC int CDECL getTimeStamp(int cameraNumber, int scanIndex, double* timestamp);
DECLSPEC int CDECL getScan(int calculationIndex, int scanIndex, int* count, double* values);
DECLSPEC int CDECL getComplexScan(int calculationIndex, int scanIndex, int* count, double* real, double* imag);

DECLSPEC int CDECL getAllScansSizes(int calculationIndex, int* rowCount, int* coloumnCount);
DECLSPEC int CDECL getAllScans(int calculationIndex, unsigned short* values);
DECLSPEC int CDECL writeAllScansToFile(int calculationIndex, const char* filename, bool writeTimestamps);

DECLSPEC int CDECL getPDValues(int pdNumber, int pdChannel, int* count, double* values);
DECLSPEC int CDECL getPDReference(int pdNumber, int pdChannel, double* value);

DECLSPEC int CDECL getAUXStates(int cameraNumber, int* count, bool* values);

DECLSPEC int CDECL getLastErrorMessage(char* errorMessage);

DECLSPEC int CDECL runUSBCommsTest();

#ifdef __cplusplus
}
#endif

#endif // _GLAZLIB_H
